"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const events_1 = __importDefault(require("events"));
class BulkSender extends events_1.default {
    constructor(client, { delay, size } = {}) {
        super();
        this.flushing = false;
        this.buffer = [];
        this.client = client;
        this.delayMillis = delay !== null && delay !== void 0 ? delay : 1000;
        this.size = size !== null && size !== void 0 ? size : 1000;
    }
    filled() {
        return Boolean(this.buffer.length);
    }
    isFlushing() {
        return this.flushing;
    }
    delay() {
        clearTimeout(this.timeout);
        this.timeout = setTimeout(() => {
            this.flush();
        }, this.delayMillis);
    }
    flush() {
        const len = this.buffer.length;
        clearTimeout(this.timeout);
        if (len) {
            this.flushing = true;
            this.client
                .bulk({ operations: this.buffer })
                .then(res => {
                if (Array.isArray(res.items)) {
                    res.items.forEach(item => {
                        if (item.index.error) {
                            console.error('elasticsearch sync error:', item.index);
                        }
                    });
                }
                this.emit('sent', len);
            })
                .catch(err => {
                this.emit('error', err);
            })
                .finally(() => {
                this.flushing = false;
            });
            this.buffer = [];
        }
    }
    push(...args) {
        let sending = false;
        if (args.length) {
            this.buffer.push(...args);
            sending = this.buffer.length >= this.size;
            if (sending) {
                this.flush();
            }
            else {
                this.delay();
            }
        }
        return sending;
    }
}
exports.default = BulkSender;
//# sourceMappingURL=bulk-sender.js.map