"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ESType = void 0;
var ESType;
(function (ESType) {
    /**
     * Defines an alias for an existing field.
     */
    ESType["Alias"] = "alias";
    /**
     * A signed 64-bit integer with a minimum value of -263 and a maximum value
     * of 2^63-1.
     */
    ESType["Long"] = "long";
    /**
     * A signed 32-bit integer with a minimum value of -231 and a maximum value
     * of 2^31-1.
     */
    ESType["Integer"] = "integer";
    /**
     * A signed 16-bit integer with a minimum value of -32,768 and a maximum
     * value of 32,767.
     */
    ESType["Short"] = "short";
    /**
     * A signed 8-bit integer with a minimum value of -128 and a maximum value of
     * 127.
     */
    ESType["Byte"] = "byte";
    /**
     * A double-precision 64-bit IEEE 754 floating point number, restricted to
     * finite values.
     */
    ESType["Double"] = "double";
    /**
     * A single-precision 32-bit IEEE 754 floating point number, restricted to
     * finite values.
     */
    ESType["Float"] = "float";
    /**
     * A half-precision 16-bit IEEE 754 floating point number, restricted to
     * finite values.
     */
    ESType["HalfFloat"] = "half_float";
    /**
     * A floating point number that is backed by a long, scaled by a fixed double
     * scaling factor.
     */
    ESType["ScaledFloat"] = "scaled_float";
    /**
     * An unsigned 64-bit integer with a minimum value of 0 and a maximum value
     * of 2^64-1.
     */
    ESType["UnsignedLong"] = "unsigned_long";
    /**
     * Binary value encoded as a Base64 string.
     */
    ESType["Binary"] = "binary";
    /**
     * True and false values.
     */
    ESType["Boolean"] = "boolean";
    /**
     * Used for structured content such as IDs, email addresses, hostnames,
     * status codes, zip codes, or tags.
     */
    ESType["Keyword"] = "keyword";
    /**
     * For keyword fields that always contain the same value.
     */
    ESType["ConstantKeyword"] = "constant_keyword";
    /**
     * For unstructured machine-generated content. The wildcard type is optimized
     * for fields with large values or high cardinality.
     */
    ESType["Wildcard"] = "wildcard";
    /**
     * JSON doesn’t have a date data type, so dates in Elasticsearch can either
     * be: strings containing formatted dates, e.g. "2015-01-01" or "2015/01/01
     * 12:10:30"; a number representing milliseconds-since-the-epoch; a number
     * representing seconds-since-the-epoch.
     */
    ESType["Date"] = "date";
    /**
     * This data type is an addition to the date data type. However there is an
     * important distinction between the two. The existing date data type stores
     * dates in millisecond resolution. The date_nanos data type stores dates in
     * nanosecond resolution, which limits its range of dates from roughly 1970
     * to 2262, as dates are still stored as a long representing nanoseconds
     * since the epoch.
     */
    ESType["DateNanos"] = "date_nanos";
    /**
     * A JSON object.
     */
    ESType["Object"] = "object";
    /**
     * An entire JSON object as a single field value.
     */
    ESType["Flattened"] = "flattened";
    /**
     * A JSON object that preserves the relationship between its subfields.
     */
    ESType["Nested"] = "nexted";
    /**
     * Defines a parent/child relationship for documents in the same index.
     */
    ESType["Join"] = "join";
    /**
     * A range of signed 32-bit integers with a minimum value of -2^31 and
     * maximum of 2^31-1.
     */
    ESType["IntegerRange"] = "integer_range";
    /**
     * A range of single-precision 32-bit IEEE 754 floating point values.
     */
    ESType["FloatRange"] = "float_range";
    /**
     * A range of signed 64-bit integers with a minimum value of -2^63 and maximum
     * of 2^63-1.
     */
    ESType["LongRange"] = "long_range";
    /**
     * A range of double-precision 64-bit IEEE 754 floating point values.
     */
    ESType["DoubleRange"] = "double_range";
    /**
     * A range of date values. Date ranges support various date formats through
     * the format mapping parameter. Regardless of the format used, date values
     * are parsed into an unsigned 64-bit integer representing milliseconds since
     * the Unix epoch in UTC. Values containing the now date math expression are
     * not supported.
     */
    ESType["DateRange"] = "date_range";
    /**
     * A range of ip values supporting either IPv4 or IPv6 (or mixed) addresses.
     */
    ESType["IpRange"] = "ip_range";
    /**
     * IPv4 and IPv6 addresses.
     */
    ESType["Ip"] = "ip";
    /**
     * Software versions. Supports Semantic Versioning precedence rules.
     */
    ESType["Version"] = "version";
    /**
     * Compute and stores hashes of values.
     */
    ESType["Murmur3"] = "murmur3";
    /**
     * Pre-aggregated metric values.
     */
    ESType["AggregateMetricDouble"] = "aggregate_metric_double";
    /**
     * Pre-aggregated numerical values in the form of a histogram.
     */
    ESType["Histogram"] = "histogram";
    /**
     * The traditional field type for full-text content such as the body of an
     * email or the description of a product.
     */
    ESType["Text"] = "text";
    /**
     * A space-optimized variant of text that disables scoring and performs
     * slower on queries that need positions. It is best suited for indexing log
     * messages.
     */
    ESType["MatchOnlyText"] = "match_only_text";
    /**
     * Used for auto-complete suggestions.
     */
    ESType["Completion"] = "completion";
    /**
     * Text-like type for as-you-type completion.
     */
    ESType["SearchAsYouType"] = "search_as_you_type";
    /**
     * A count of tokens in a text.
     */
    ESType["TokenCount"] = "token_count";
    /**
     * Records dense vectors of float values.
     */
    ESType["DenseVector"] = "dense_vector";
    /**
     * Records sparse vectors of float values.
     */
    ESType["SparseVector"] = "sparse_vector";
    /**
     * Records a numeric feature to boost hits at query time.
     */
    ESType["RankFeature"] = "rank_feature";
    /**
     * Records numeric features to boost hits at query time.
     */
    ESType["RankFeatures"] = "rank_features";
    /**
     * Latitude and longitude points.
     */
    ESType["GeoPoint"] = "geo_point";
    /**
     * Complex shapes, such as polygons.
     */
    ESType["GeoShape"] = "geo_shape";
    /**
     * Arbitrary cartesian points.
     */
    ESType["Point"] = "point";
    /**
     * Arbitrary cartesian geometries.
     */
    ESType["Shape"] = "shape";
})(ESType = exports.ESType || (exports.ESType = {}));
//# sourceMappingURL=es-type.js.map