"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generate = void 0;
const utils_1 = require("./utils");
const lodash_1 = require("lodash");
const es_type_1 = require("./es-type");
function generate(schema) {
    var _a;
    const mapping = {};
    const typeKey = getTypeKey(schema);
    const explicit = hasExplicit(schema, typeKey);
    const defaultTypes = {
        objectid: es_type_1.ESType.Keyword,
        number: es_type_1.ESType.Long,
        mixed: es_type_1.ESType.Object,
        string: es_type_1.ESType.Text,
    };
    Object.keys(schema.paths).forEach(name => {
        var _a, _b, _c, _d;
        if (name === '_id') {
            return;
        }
        const path = schema.paths[name];
        const options = getOptions(path, typeKey);
        const type = (0, utils_1.getType)(path);
        if (explicit &&
            isEmbedded(type) &&
            !(0, lodash_1.get)(options, 'elasticsearch.indexed')) {
            (0, lodash_1.set)(options, 'elasticsearch.indexed', hasExplicit(path.schema, typeKey));
        }
        if (explicit && !((_a = options.elasticsearch) === null || _a === void 0 ? void 0 : _a.indexed)) {
            return;
        }
        let current = mapping;
        const names = name.split('.');
        // handle plain object
        if (names.length > 1) {
            names.forEach((name, index) => {
                if (index === names.length - 1) {
                    // last item is the target
                    current = current[name] = { type, ...(0, utils_1.getExtraOptions)(options) };
                }
                else {
                    if (!current[name]) {
                        current[name] = { type: 'object', properties: {} };
                    }
                    current = current[name].properties;
                }
            });
        }
        else {
            current = mapping[name] = { type, ...(0, utils_1.getExtraOptions)(options) };
        }
        if (Object.values(es_type_1.ESType).includes((_b = options.elasticsearch) === null || _b === void 0 ? void 0 : _b.type)) {
            current.type = options.elasticsearch.type;
        }
        if (((_c = options.elasticsearch) === null || _c === void 0 ? void 0 : _c.type) && (0, lodash_1.isObject)(options.elasticsearch.type)) {
            current.type = 'object';
            current.properties = generateESTypeMapping(options.elasticsearch.type);
        }
        else {
            if (!(0, lodash_1.get)(options, 'elasticsearch.value') &&
                !((_d = options.elasticsearch) === null || _d === void 0 ? void 0 : _d.type)) {
                if (isEmbedded(type)) {
                    current.type = 'object';
                    current.properties = generate(path.schema);
                }
                if (defaultTypes[type]) {
                    current.type = defaultTypes[type];
                }
            }
        }
        if ((0, lodash_1.get)(options, 'elasticsearch.value')) {
            current.value = (0, lodash_1.isFunction)(options.elasticsearch.value)
                ? options.elasticsearch.value
                : function () {
                    return options.elasticsearch.value;
                };
        }
    });
    delete mapping[schema.get('versionKey')];
    if (schema.options && ((_a = schema.options.elasticsearch) === null || _a === void 0 ? void 0 : _a.extend)) {
        Object.assign(mapping, generateESTypeMapping(schema.options.elasticsearch.extend, true));
    }
    return mapping;
}
exports.generate = generate;
function isEmbedded(type) {
    return type === 'embedded' || type === 'array';
}
function getTypeKey(schema) {
    var _a, _b;
    return (_b = (_a = schema.options.elasticsearch) === null || _a === void 0 ? void 0 : _a.typeKey) !== null && _b !== void 0 ? _b : 'type';
}
function hasExplicit(schema, typeKey) {
    return schema && schema.paths
        ? Object.keys(schema.paths).some(name => {
            if (name === '_id') {
                return;
            }
            const path = schema.paths[name];
            const type = (0, utils_1.getType)(path);
            if (isEmbedded(type)) {
                if (hasExplicit(path.schema, getTypeKey(path.schema))) {
                    return true;
                }
            }
            return (0, lodash_1.get)(getOptions(path, typeKey), 'elasticsearch.indexed');
        })
        : false;
}
function getOptions(path, typeKey) {
    if (Array.isArray(path.options[typeKey]) &&
        path.options[typeKey].length === 1 &&
        path.options[typeKey][0].ref) {
        return path.options[typeKey][0];
    }
    return path.options;
}
function generateESTypeMapping(content, esExtendMode) {
    const properties = {};
    Object.keys(content).forEach(key => {
        var _a, _b;
        if (content[key] && (0, lodash_1.isObject)(content[key])) {
            properties[key] = {};
            if (((_a = content[key].elasticsearch) === null || _a === void 0 ? void 0 : _a.type) &&
                (0, lodash_1.isObject)((_b = content[key].elasticsearch) === null || _b === void 0 ? void 0 : _b.type)) {
                properties[key].type = 'object';
                properties[key].properties = generateESTypeMapping(content[key].elasticsearch.type, esExtendMode);
            }
            else {
                Object.keys(content[key]).forEach(subKey => {
                    let value = content[key][subKey];
                    const original = value;
                    if (subKey === 'value' && esExtendMode) {
                        value = function (_, context) {
                            return (0, lodash_1.isFunction)(original)
                                ? original(context.document)
                                : original;
                        };
                    }
                    properties[key][subKey] = value;
                });
            }
        }
    });
    return properties;
}
//# sourceMappingURL=mapping.js.map