"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.esIndex = exports.esOptions = exports.getIndexName = void 0;
const utils = __importStar(require("./utils"));
const lodash_1 = require("lodash");
const bulk_sender_1 = __importDefault(require("./bulk-sender"));
const mapping_1 = require("./mapping");
function getIndexName(collectionName) {
    const lowercase = collectionName.toLowerCase();
    if (process.env.NODE_ENV === 'test') {
        return `test_${lowercase}`;
    }
    if (process.env.NODE_ENV === 'development') {
        return `development_${lowercase}`;
    }
    return lowercase;
}
exports.getIndexName = getIndexName;
const esOptions = options => {
    let _options = null;
    return function esOptions() {
        if (_options)
            return _options;
        _options = (0, lodash_1.cloneDeep)(options);
        if (!options.index) {
            _options.index = getIndexName(this.collection.name);
        }
        if (!_options.index) {
            throw new Error('Missing collection name to build Elasticsearch index');
        }
        if (options.bulk) {
            _options.bulker = new bulk_sender_1.default(options.client, options.bulk);
        }
        _options.mapping = Object.freeze({
            properties: (0, mapping_1.generate)(this.schema),
        });
        return _options;
    };
};
exports.esOptions = esOptions;
async function esIndex(update) {
    const esOptions = this.esOptions();
    let body = utils.serialize(this, esOptions.mapping);
    if ((0, lodash_1.isFunction)(esOptions.transform)) {
        const transformedBody = esOptions.transform(body);
        if (transformedBody) {
            body = transformedBody;
        }
    }
    if (update && update.unset) {
        const unset = (0, lodash_1.isString)(update.unset) ? [update.unset] : update.unset;
        unset.forEach(field => {
            body[field] = null;
        });
    }
    const payload = {
        index: esOptions.index,
        id: this._id.toString(),
        body: update ? { doc: body } : body,
    };
    if (update) {
        return esOptions.client.update(payload);
    }
    return esOptions.client.index(payload);
}
exports.esIndex = esIndex;
//# sourceMappingURL=methods.js.map