"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.esCreateMapping = void 0;
const lodash_1 = require("lodash");
const chalk_1 = __importDefault(require("chalk"));
const utils_1 = require("../utils");
async function esCreateMapping(options) {
    const { index, mappingSettings, mapping, client } = this.esOptions();
    if (await this.esExists()) {
        if (options === null || options === void 0 ? void 0 : options.delete) {
            (0, utils_1.esLog)(`deleting map for ${chalk_1.default.cyan(index)}`);
            await this.esDeleteIndex();
        }
        else {
            return client.indices.putMapping({
                index,
                body: mapping,
            });
        }
    }
    if (await this.esExists())
        return;
    (0, utils_1.esLog)(`creating map for ${chalk_1.default.cyan(index)}`);
    return await client.indices.create({
        index,
        body: (0, lodash_1.merge)({
            settings: {
                analysis: {
                    analyzer: {
                        folding: {
                            tokenizer: 'standard',
                            filter: ['lowercase', 'asciifolding'],
                        },
                    },
                },
                // number_of_shards: 5,
            },
            mappings: {
                ...mapping,
            },
        }, mappingSettings),
    });
}
exports.esCreateMapping = esCreateMapping;
//# sourceMappingURL=es-create-mapping.js.map