"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.esSync = void 0;
const mongoose_1 = __importDefault(require("mongoose"));
const bulk_sender_1 = __importDefault(require("../bulk-sender"));
const utils = __importStar(require("../utils"));
const utils_1 = require("../utils");
const chalk_1 = __importDefault(require("chalk"));
function esSync(conditions, projection, options) {
    const model = this;
    return new Promise((resolve, reject) => {
        var _a, _b;
        const start = Date.now();
        const esOptions = model.esOptions();
        const batch = (_b = (_a = esOptions === null || esOptions === void 0 ? void 0 : esOptions.bulk) === null || _a === void 0 ? void 0 : _a.batch) !== null && _b !== void 0 ? _b : 50;
        (0, utils_1.esLog)(`started synchronizing ${chalk_1.default.cyan(esOptions.index)}`);
        let query;
        if (conditions instanceof mongoose_1.default.Query) {
            query = conditions.lean().batchSize(batch);
        }
        else {
            query = model
                .find(conditions || {}, projection, options)
                .lean()
                .batchSize(batch);
        }
        const stream = query.cursor();
        const bulker = esOptions.bulker || new bulk_sender_1.default(esOptions.client);
        let streamClosed = false;
        function finalize() {
            bulker.removeListener('error', onError);
            bulker.removeListener('sent', onSent);
            esOptions.client.indices
                .refresh({ index: esOptions.index })
                .then(resolve)
                .catch(reject)
                .finally(() => {
                (0, utils_1.esLog)(`finished synchronizing ${chalk_1.default.cyan(esOptions.index)} ${chalk_1.default.gray(Date.now() - start, 'ms')}`);
            });
        }
        function onError(err) {
            model.emit('es-bulk-error', err);
            if (streamClosed) {
                finalize();
            }
            else {
                stream.resume();
            }
        }
        function onSent(len) {
            model.emit('es-bulk-sent', len);
            if (streamClosed) {
                finalize();
            }
            else {
                stream.resume();
            }
        }
        bulker.on('error', onError);
        bulker.on('sent', onSent);
        stream.on('data', doc => {
            stream.pause();
            let sending;
            if (!esOptions.filter || esOptions.filter(doc)) {
                sending = bulker.push({
                    index: {
                        _index: esOptions.index,
                        _type: esOptions.type,
                        _id: doc._id.toString(),
                    },
                }, utils.serialize(doc, esOptions.mapping));
                model.emit('es-bulk-data', doc);
            }
            else {
                model.emit('es-bulk-filtered', doc);
            }
            if (!sending) {
                stream.resume();
            }
        });
        stream.on('end', () => {
            streamClosed = true;
            if (bulker.filled()) {
                bulker.flush();
            }
            else if (!bulker.isFlushing()) {
                finalize();
            }
        });
    });
}
exports.esSync = esSync;
//# sourceMappingURL=es-sync.js.map