"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.esLog = exports.isTest = exports.getExtraOptions = exports.getType = exports.serialize = exports.getUndefineds = void 0;
const lodash_1 = require("lodash");
const mongoose_1 = __importDefault(require("mongoose"));
const chalk_1 = __importDefault(require("chalk"));
function getUndefineds(document, mapping) {
    let field;
    const result = [];
    for (field in mapping.properties) {
        if ({}.hasOwnProperty.call(mapping.properties, field)) {
            if (document[field] === undefined && document.isModified(field)) {
                result.push(field);
            }
        }
    }
    return result;
}
exports.getUndefineds = getUndefineds;
function serialize(document, mapping, main) {
    let name;
    main = main !== null && main !== void 0 ? main : document;
    function _serializeObject(object, mappingData) {
        const serialized = {};
        Object.keys(mappingData.properties).forEach(field => {
            let value;
            const property = mappingData.properties[field];
            try {
                if ({}.hasOwnProperty.call(property, 'value')) {
                    value = (0, lodash_1.isFunction)(property.value)
                        ? property.value(object[field], {
                            document: main,
                            container: object,
                            field,
                        })
                        : property.value;
                }
                else if (object[field] !== undefined) {
                    value = serialize.call(object, object[field], property, main);
                }
                if (value !== undefined) {
                    serialized[field] = value;
                }
            }
            catch (err) {
                // do nothing
            }
        });
        if (!Object.keys(serialized).length &&
            (typeof object !== 'object' || object instanceof mongoose_1.default.Types.ObjectId)) {
            return;
        }
        return serialized;
    }
    if (mapping.properties && document) {
        if (Array.isArray(document)) {
            return document.map(object => _serializeObject(object, mapping));
        }
        return _serializeObject(document, mapping);
    }
    if (document && typeof document === 'object') {
        name = document.constructor.name;
        if (name === 'model') {
            return document.id;
        }
        if (name === 'ObjectID') {
            return document.toString();
        }
        if (name === 'Date') {
            return new Date(document).toJSON();
        }
    }
    return document;
}
exports.serialize = serialize;
function getType(path) {
    var _a, _b;
    return ((_b = (_a = path.caster) === null || _a === void 0 ? void 0 : _a.instance) !== null && _b !== void 0 ? _b : path.instance).toLowerCase();
}
exports.getType = getType;
function getExtraOptions(options) {
    return (0, lodash_1.omit)(options.elasticsearch, 'indexed', 'type', 'value');
}
exports.getExtraOptions = getExtraOptions;
exports.isTest = process.env.NODE_ENV === 'test';
function esLog(...args) {
    if (exports.isTest) {
        console.log(chalk_1.default.yellow(...args));
    }
}
exports.esLog = esLog;
//# sourceMappingURL=utils.js.map